@@ -901,6 +901,7 @@ class Paste(Event, bubble=True):
         yield "text", self.text
 
 
+@dataclass
 class ScreenResume(Event, bubble=False):
     """Sent to screen that has been made active.
 
@@ -908,6 +909,12 @@ class ScreenResume(Event, bubble=False):
     - [ ] Verbose
     """
 
+    refresh_styles: bool = True
+    """Should the resuming screen refresh its styles?"""
+
+    def __rich_repr__(self) -> rich.repr.Result:
+        yield self.refresh_styles
+
 
 class ScreenSuspend(Event, bubble=False):
     """Sent to screen when it is no longer active.
